#!/usr/bin/env bash

###
# Variabeln setzung
###

# Linux distro
script_distro='Linux Mint'

# Zusätzliche packete
more_packages=""

###
# Funktionen
###
function _addToDefaultPackages() {
  more_packages="${more_packages} ${1}"
}


###
# Difiniere liste der zusätzlichen Software
###

# Grafik
_addToDefaultPackages "cheese"
_addToDefaultPackages "inkscape"

# Office
_addToDefaultPackages "libreoffice"

# Sicherheit
_addToDefaultPackages "keepassxc"

# Spiele
_addToDefaultPackages "0ad"
_addToDefaultPackages "beneath-a-steel-sky"
_addToDefaultPackages "billard-gl"
_addToDefaultPackages "blobby"
_addToDefaultPackages "blockout2"
_addToDefaultPackages "flight-of-the-amazon-queen"
_addToDefaultPackages "freeciv"
_addToDefaultPackages "frozen-bubble"
_addToDefaultPackages "gbrainy"
_addToDefaultPackages "gnome-games"
_addToDefaultPackages "gweled"
_addToDefaultPackages "hedgewars"
_addToDefaultPackages "lincity-ng"
_addToDefaultPackages "lure-of-the-temptress"
_addToDefaultPackages "openttd"
_addToDefaultPackages "pingus"
_addToDefaultPackages "pipewalker"
_addToDefaultPackages "pokerth"
_addToDefaultPackages "supertux"
_addToDefaultPackages "supertuxkart"
_addToDefaultPackages "teeworlds"
_addToDefaultPackages "wesnoth"
_addToDefaultPackages "widelands"

# Spiele Plattformen
_addToDefaultPackages "playonlinux"
_addToDefaultPackages "steam"
_addToDefaultPackages "wine-stable"
_addToDefaultPackages "winetricks"

# Systemverwaltung
_addToDefaultPackages "gparted"

# Tools
_addToDefaultPackages "shutter"
_addToDefaultPackages "vim"

# Verwaltung
_addToDefaultPackages "calibre"

# Wissen
_addToDefaultPackages "goldendict"
_addToDefaultPackages "hardinfo"
_addToDefaultPackages "ubuntu-edu-preschool"
_addToDefaultPackages "ubuntu-edu-primary"
_addToDefaultPackages "ubuntu-edu-secondary"
_addToDefaultPackages "ubuntu-edu-tertiary"


###
# Begrüßung
###
echo "\
##############################
# Computertruhe setup script #
##############################

###
# Meintainer: Computertruhe e. V.
# Website:    https://computertruhe.de/
# Version:    0.1.3
# Repo:       https://codeberg.org/Computertruhe/computertruhe-setup
# Ditro:      ${script_distro}
###
"
echo ">>> Starte initiales Setup für Rechner mit frisch installiertem ${script_distro} ..."


###
# Automatisierung
###
echo ">>> Automatische Installation empfohlener Pakete aktivieren ..."
sudo sed -i 's/false/true/g' /etc/apt/apt.conf.d/00recommends

echo ">>> Besten Spiegelserver für Linux Mint auswählen ..."
mint-switch-to-local-mirror

echo ">>> Paketquellen aktualisieren ..."
apt update

echo ">>> System aktualisieren (apt) ..."
DEBIAN_FRONTEND=noninteractive apt full-upgrade --yes

echo ">>> System aktualisieren (mintupdate-cli) ..."
DEBIAN_FRONTEND=noninteractive mintupdate-cli upgrade --yes

echo ">>> Proprietäre Treiber installieren (sofern verfügbar) ..."
ubuntu-drivers autoinstall

echo ">>> Zusätzliche Software installieren ..."
DEBIAN_FRONTEND=noninteractive apt install ${more_packages} --yes

echo ">>> Sprachpakete 'ar' und 'fa' installieren ..."
apt install language-pack-ar language-pack-gnome-ar language-pack-fa language-pack-gnome-fa --yes
echo ">>> Sprachunterstützung vervollständigen ..."
apt install language-selector-common --yes
apt install $(check-language-support) --yes
echo ">>> Unnötige Pakete entfernen ..."
apt clean
apt autoremove --yes
echo ">>> Rootshell beenden ..."
exit


###
# Abschluss
###
echo ">>> Initiales Setup beendet."
echo
echo ">>> To-dos:"
echo ">>> - Sprachpakete komplettieren"
echo ">>> - Arabisches und persisches Tastatur-Layout einrichten"
